@@ -167,6 +167,14 @@ on_key_pressed_cb (GtkWidget *w, GdkEvent *event, gpointer user_data)
         }
       break;
 
+    case GDK_KEY_F10:
+      if ((event->key.state & modifiers) != GDK_CONTROL_MASK)
+        {
+          bjb_main_toolbar_open_menu (self->main_toolbar);
+          return TRUE;
+        }
+      break;
+
     case GDK_KEY_F2:
     case GDK_KEY_F3:
     case GDK_KEY_F4:
@@ -175,7 +183,6 @@ on_key_pressed_cb (GtkWidget *w, GdkEvent *event, gpointer user_data)
     case GDK_KEY_F7:
     case GDK_KEY_F8:
     case GDK_KEY_F9:
-    case GDK_KEY_F10:
     case GDK_KEY_F11:
       return TRUE;
 
@@ -283,6 +290,18 @@ on_trash_cb (GSimpleAction *action,
   biji_item_trash (BIJI_ITEM (note));
 }
 
+static void
+on_close (GSimpleAction *action,
+          GVariant      *parameter,
+          gpointer       user_data)
+{
+  GtkApplicationWindow *window;
+
+  window = GTK_APPLICATION_WINDOW (user_data);
+
+  gtk_window_close (GTK_WINDOW (window));
+}
+
 static void
 bjb_window_base_save_geometry (BjbWindowBase *self)
 {
@@ -308,6 +327,7 @@ bjb_window_base_load_geometry (BjbWindowBase *self)
 static void
 bjb_window_base_destroy (gpointer a, BjbWindowBase * self)
 {
+  bjb_main_view_disconnect_scrolled_window (self->view);
   bjb_controller_disconnect (self->controller);
   bjb_window_base_save_geometry (self);
 }
@@ -338,6 +358,7 @@ static GActionEntry win_entries[] = {
   { "view-notebooks", on_view_notebooks_cb, NULL, NULL, NULL },
   { "email", on_email_cb, NULL, NULL, NULL },
   { "trash", on_trash_cb, NULL, NULL, NULL },
+  { "close", on_close },
 };
 
 /* Gobj */
